@@ -26,9 +26,7 @@
 #ifndef NAUTILUS_CLIPBOARD_H
 #define NAUTILUS_CLIPBOARD_H
 
-#include <gtk/gtkeditable.h>
-#include <gtk/gtktextview.h>
-#include <gtk/gtkuimanager.h>
+#include <gtk/gtk.h>
 
 /* This makes this editable or text view put clipboard commands into
  * the passed UI manager when the editable/text view is in focus.
@@ -37,14 +35,20 @@
 /* The shares selection changes argument should be set to true if the
  * widget uses the signal "selection_changed" to tell others about
  * text selection changes.  The NautilusEntry widget
- * is currently the only widget in nautilus that shares selection
- * changes. This feature currently only works for GtkEditables. */
+ * is currently the only editable in nautilus that shares selection
+ * changes. */
 void nautilus_clipboard_set_up_editable            (GtkEditable        *target,
 						    GtkUIManager       *ui_manager,
 						    gboolean            shares_selection_changes);
 void nautilus_clipboard_set_up_text_view           (GtkTextView        *target,
-						    GtkUIManager       *ui_manager,
-						    gboolean            shares_selection_changes);
-
+						    GtkUIManager       *ui_manager);
+void nautilus_clipboard_clear_if_colliding_uris    (GtkWidget          *widget,
+						    const GList        *item_uris,
+						    GdkAtom             copied_files_atom);
+GtkClipboard* nautilus_clipboard_get                (GtkWidget          *widget);
+GList* nautilus_clipboard_get_uri_list_from_selection_data
+						   (GtkSelectionData   *selection_data,
+						    gboolean           *cut,
+						    GdkAtom             copied_files_atom);
 
 #endif /* NAUTILUS_CLIPBOARD_H */
